@@ -69,6 +69,9 @@ from ._clusters import (
     _ConfigCluster,
     _EFSPerformanceMode,
     _EFSThroughputMode,
+    _EnergyConfig,
+    _EnergySchedule,
+    _EnergySchedulePeriod,
     _GoogleCloudProvider,
     _GoogleFilestoreTier,
     _GoogleStorage,
@@ -143,7 +146,7 @@ from ._url_utils import CLUSTER_SCHEMES as SCHEMES
 from ._users import Action, Permission, Quota, Share, Users
 from ._utils import _ContextManager, find_project_root
 
-__version__ = "22.7.1"
+__version__ = "23.2.0"
 
 
 __all__ = (
@@ -259,6 +262,9 @@ __all__ = (
     "_ConfigCluster",
     "_EFSPerformanceMode",
     "_EFSThroughputMode",
+    "_EnergyConfig",
+    "_EnergySchedule",
+    "_EnergySchedulePeriod",
     "_GoogleCloudProvider",
     "_GoogleFilestoreTier",
     "_GoogleStorage",
@@ -345,6 +351,6 @@ async def login_headless(
 async def logout(
     *,
     path: Optional[Path] = None,
-    show_browser_cb: Callable[[URL], Awaitable[None]] = None,
+    show_browser_cb: Optional[Callable[[URL], Awaitable[None]]] = None,
 ) -> None:
     await Factory(path).logout(show_browser_cb)
