@@ -346,22 +346,25 @@ def _open_db_rw(
     path.chmod(0o700)  # fix security if config folder already exists
 
     config_file = path / "db"
-    with sqlite3.connect(str(config_file)) as db:
+    conn = sqlite3.connect(str(config_file))
+    try:
         # forbid access to other users
         os.chmod(config_file, 0o600)
 
-        db.row_factory = sqlite3.Row
-        try:
+        conn.row_factory = sqlite3.Row
+        with conn as db:
             db.execute("PRAGMA journal_mode=WAL")
             yield db
-        except sqlite3.DatabaseError as exc:
-            if not suppress_errors:
-                raise
-            msg = "Cannot send the usage statistics: %s"
-            if str(exc) != "database is locked":
-                logger.warning(msg, repr(exc))
-            else:
-                logger.debug(msg, repr(exc))
+    except sqlite3.DatabaseError as exc:
+        if not suppress_errors:
+            raise
+        msg = "Cannot send the usage statistics: %s"
+        if str(exc) != "database is locked":
+            logger.warning(msg, repr(exc))
+        else:
+            logger.debug(msg, repr(exc))
+    finally:
+        conn.close()
 
 
 @contextlib.contextmanager
@@ -395,14 +398,18 @@ def _open_db_ro(
                 f"run 'chmod 600 {config_file}' first"
             )
 
-    with sqlite3.connect(str(config_file)) as db:
+    conn = sqlite3.connect(str(config_file))
+    try:
         # forbid access for other users
         os.chmod(config_file, 0o600)
 
         if not skip_schema_check:
-            _check_db(db)
-        db.row_factory = sqlite3.Row
-        yield db
+            _check_db(conn)
+        conn.row_factory = sqlite3.Row
+        with conn as db:
+            yield db
+    finally:
+        conn.close()
 
 
 def _load(path: Path) -> _ConfigData:
